function nivel = niveis(wc,L,qmf,J)
% NIVEIS   Multi-Resolution Display of 1-d Wavelet Transform
%          Criao niveis wavelets na variavel nivel
%  Usage
%    nivel = niveis(wc,L,qmf,J)
%  Inputs
%    wc    1-d wavelet transform
%    L     level of coarsest scale
%    qmf   quadrature mirror filter used to make wc
%    J	   number of wavelet levels (usually the length of wc)
%
%  Side Effects
%    A depiction of the multi-resolution decomposition
%    of the signal, as in S. Mallat.
%
%  See Also
%    PlotWaveCoeff, FWT_PO, IWT_PO, MakeONFilter, plotmra (PC),
%    PlotMultiRes (Unix)
    wavecoef = ShapeAsRow(wc);
		
	[n,Jota] = dyadlength(wavecoef); 
	if strcmp(J,'') 
		J = Jota;
	end
	nivel=zeros(J,n);
%
	t = (1:n);
	for j=(J-1):-1:L
	   a=j+1;
	   w = zeros(1,n);
	   w(dyad(j)) = wavecoef(dyad(j));
	   nivel(a,:) = IWT_PO(w,j,qmf);
	end
%
	w = zeros(1,n);
	w(1:2^(L)) = wavecoef(1:2^(L));
	nivel((L+1),:) = IWT_PO(w,L,qmf);

% Adapted from WaveLab version .701
% RRAF 1996/97 (23.2.97)
