function plotwcf(wx,L,scal,nivlcf)
%
% PLOTWCF Spike-plot display of wavelet coefficients
%
%  Usage
%    plotwcf(wx,L,scal,nivlcf)
%  Inputs
%    wx    1-d wavelet transform
%    L     level of coarsest scale
%    scal  scale factor [0 ==> autoscale]
%    nivlcf nivel de coeficientes desejado para plotar (opcional)
%  Side Effects
%    A display of wavelet coefficients (coarsest level 
%    NOT included) by level and position.
%
%  See Also
%    plotwmra (Unix/PC), plotmra, fwt_po, iwt_po, plotspikes (PC) and
%    PlotMultiRes, FWT_PO, IWT_PO, PlotSpikes (Unix)
%
    wavecoef = ShapeAsRow(wx);
	[n,J] = dyadlength(wavecoef); 
	if scal==0, 
		scal = 1. / max(abs(wavecoef((2^(L)+1):n))); 
	end
%
if (~exist('nivlcf'))
	LockAxes([0 1 (-J) (-L+1)])
	for j=(J-1):-1:L
	  tj = (.5:(2^(j)-.5))./2^(j);
	  PlotSpikes(-j,tj,(wavecoef(dyad(j)).*scal));
	end
	UnlockAxes;
else
	LockAxes([0 1 -1 1])
	tj = (.5:(2^(nivlcf)-.5))./2^(nivlcf);
	PlotSpikes(0,tj,(wavecoef(dyad(nivlcf)).*scal));
	UnlockAxes
end

% Copyright (c) 1993. David L. Donoho
% 1997 RRossiAFaria    
      

