function plotwmra(wx,L,scal,qmf)
%
% PLOTWMRA(wx,L,scal,qmf)
%	
%	 Multi-Resolution Display of 1-d Wavelet Transform
%        Exibe numa s figura todos os nveis da WMRA desde o
%	 nivel mais grosso (L) ao mais fino.
%
%  Usage
%    plotwmra(wx,L,scal,qmf)
%  Input
%    wx    1-d wavelet transform
%    L     level of coarsest scale
%    scal  scale factor [0 ==> autoscale]
%
%  Side Effects
%    A depiction of the multi-resolution decomposition
%    of the signal, as in S. Mallat.
%
%  See Also
%    PlotWaveCoeff, FWT_PO, IWT_PO, MakeONFilter, wnivel
%    
    wavecoef = ShapeAsRow(wx);
	if scal==0, 
		scal = 1. / max(abs(wavecoef)); 
	end
	[n,J] = dyadlength(wavecoef); 
%
	figure(3);
	LockAxes([0 n -(J) (-L+2)]);
	t = (1:n);
	for j=(J-1):-1:L
	   w = zeros(1,n);
	   w(dyad(j)) = wavecoef(dyad(j));
	   nivelj = IWT_PO(w,j,qmf);
	   plot(t,-(j) + scal.*nivelj);
	end
	clear nivelj;
%
	w = zeros(1,n);
	w(1:2^(L)) = wavecoef(1:2^(L));
	nivelL = IWT_PO(w,L,qmf);
	plot(t,(-(L-1)) + scal.*nivelL);
	clear w; clear nivelL;
%
	xlabel('t'); ylabel('dyad');
	title('Decomposicao em multiresolucao');
	UnlockAxes;

%
% Copyright (c) 1993. David L. Donoho  
% 1997 RRossiAFaria
% Part of Wavesynth version 2.0, 3.0 
% Adapted from WaveLab version .701

