function salvasom(y,pr)
% SALVASOM Convert vector into sound and save it to a file .mat
%
%	SALVASOM(Y,'pr') sends the signal in vector Y to
%       be saved onto file named "pr" as a MAT sound.
%       
%      "pr" should come with extension, like "som_tal.mat".
%       If you didnot put "pr", nothing will be saved onto any files. 
%
%	Aditional information:
%
%	Vector Y is automatically scaled so that the maximum and minimum values 
%	in Y correspond to the maximum and minimum input ranges allowed by the
%	sound hardware. On the Macintosh and the SGI, the volume control on the
%	Control Panel determines the final sound level.
%
%	See also SAXIS, AUWRITE, AUREAD, WAVREAD, WAVWRITE, SOUND, SOM

%	Copyright (c) 1984-94 by The MathWorks, Inc.

global SAXIS_SCALE
global SAXIS_LIM
v = saxis;
ymin = min(y(:));
ymax = max(y(:));
if ~strcmp(SAXIS_SCALE,'auto')
  smin = v(1);
  smax = v(2);
else % auto-scale
  smin = ymin;
  smax = ymax;
  if smin == smax
    smax = smax + 1;
  end
  SAXIS_LIM = [smin smax];
end

% Scale y's values between [smin smax] onto [-1 1].
a = 2/(smax-smin);
b = (smin+smax)/(smin-smax);
y(:) = a*y+b;

% Normalizando o sinal para 16 bits de resolucao, inteiro
  xis = y+1;
  xis = xis*(32766.5) - 32766;  % projetando em [-32766 32767] (16 bits) 
  xis = round(xis);             % arredondando para ser inteiro, nao float

% salvando o sinal num arquivo cujo nome esteja na variavel pr
% obs: "pr" e' escrito no text box na interface mestre, canto inferior
%      esquerdo, e ja' deve trazer um nome valido de arquivo: "file.mat"
%      com extensao .mat e tudo. Atencao para nao tentar gravar no mesmo
%      arquivo do projeto: faca o projeto original so' de leitura!

if exist('pr') 
   if ~strcmp(pr,'')
	eval(['save ',pr,' xis']);
   end
end

% Parte do Wavesynt para Wavelab
% Adaptado a partir do original da Mathworks: sound.m
% RRAF 1997