function som(y,fs,pr)
% SOM	Convert vector into sound for real time sonorization and to save file.
%	SOM(Y,fs,'pr') sends the signal in vector Y out the speaker on SPARC, HP,
%	SGI, PC,  and Macintosh computers (the vector is autoscaled to provide
%	maximum amplitude) and save the sound onto file named "pr".
%       
%      "pr" should come with extension, like "som_tal.mat".
%       If you didnot put fs, fs will be default (see below). 
%       If you didnot put "pr", nothing will be saved onto any files. 
%
%       The Interface Mestre of Wavesynth every time it sonorizes any signal
%       it tries to write the audio signal onto the file in Project text box,
%       which is put into a variable "pr". 
%       So, take care of what is in the Project text box in the Interface Mestre!!
%
%	The sound is played at the default sample rate. On the SPARC, the
%	sample rate is fixed at 8192 Hz. On the Macintosh, the default
%	sample rate is 22.255K Hz.
%
%	Aditional information:
%
%	Vector Y is automatically scaled so that the maximum and minimum values 
%	in Y correspond to the maximum and minimum input ranges allowed by the
%	sound hardware. On the Macintosh and the SGI, the volume control on the
%	Control Panel determines the final sound level.
%
%	See also SAXIS, AUWRITE, AUREAD, WAVREAD, WAVWRITE, SOUND, SALVASOM

%	Copyright (c) 1984-94 by The MathWorks, Inc.

global SAXIS_SCALE
global SAXIS_LIM
v = saxis;
ymin = min(y(:));
ymax = max(y(:));
if ~strcmp(SAXIS_SCALE,'auto')
  smin = v(1);
  smax = v(2);
else % auto-scale
  smin = ymin;
  smax = ymax;
  if smin == smax
    smax = smax + 1;
  end
  SAXIS_LIM = [smin smax];
end
c = computer;

% Scale y's values between [smin smax] onto [-1 1].
a = 2/(smax-smin);
b = (smin+smax)/(smin-smax);
y(:) = a*y+b;

if (strcmp(c,'SUN4') | strcmp(c,'HP700') | strcmp(c,'SOL2'))
  auwrite2(y);
elseif (strcmp(c(1:3),'MAC') | strcmp(c,'NEXT'))
  if nargin == 1
    playsnd(y)  % Uses MEX file in the case of NEXT
  else
    playsnd(y,fs)
  end
elseif (strcmp(c,'SGI'))
  if nargin == 1
    sonorize2(y)  % Uses rsh to send to a device/audio due to MEX file bug
  else
    sonorize2(y,fs)
  end
elseif (strcmp(c(1:2),'PC'))
  x=y+1;
  x=x*(128);
  x=floor(x);
 
% Preparando o sinal para ser sonorizado: so' 64000 bits em cada stream
  MAX_VECT_SIZE = 64000;
  vect_len=length(x);
  
  if vect_len > MAX_VECT_SIZE
    num_segs=ceil(vect_len/MAX_VECT_SIZE);
    start_ind=1:MAX_VECT_SIZE:vect_len;
    end_ind = start_ind+MAX_VECT_SIZE-1;
    end_ind(num_segs)=vect_len;

    for i=1:num_segs
      if nargin < 2
		playwave(x(start_ind(i):end_ind(i)),8192);
      else
		playwave(x(start_ind(i):end_ind(i)),fs)
      end
	end
  else
      if nargin < 2
		playwave(x,8192);
      else
		playwave(x,fs)
      end
  end
else
  error('Sound is not currently supported on this hardware platform.')
end

% Normalizando o sinal para 16 bits de resolucao, inteiro
  xis = y+1;
  xis = xis*(32766.5) - 32766;  % projetando em [-32766 32767] (16 bits) 
  xis = round(xis);             % arredondando para ser inteiro, nao float

% salvando o sinal num arquivo cujo nome esteja na variavel pr
% obs: "pr" e' escrito no text box na interface mestre, canto inferior
%      esquerdo, e ja' deve trazer um nome valido de arquivo: "file.mat"
%      com extensao .mat e tudo. Atencao para nao tentar gravar no mesmo
%      arquivo do projeto: faca o projeto original so' de leitura!

if exist('pr') 
   if ~strcmp(pr,'')
	eval(['save ',pr,' xis']);
   end
end

% Parte do Wavesynt para Wavelab
% Adaptado a partir do original da Mathworks: sound.m
% RRAF 1997 (14.5.97)