function wfft(x,fi,ff,n)
%
% WFFT(x,fi,ff,'n')
%     Calcula e plota em escala correta a fft de x entre
%     as frequencias fi (inicial) e ff (final) desejadas.
%
%     Se ff nao for especificada a frequencia de Nyquist  usada.
%     Se fi e ff nao forem especificadas, 0 e Nyquist so usadas.
%     Se desejar eixo y normalizado adicione 'n' ao final da chamada.
%     Plots sero azuis (default).
% 
% Veja tambm: WLOGLOG, PWFFT, CWFFT, CWSLOGX, WLOGLOG, WSLOGX, WSLOGY
   
global samplingrate;		% (fs=44100 Hz)
if (~exist('samplingrate')) | (strcmp(samplingrate,'')) 
	disp('Warning: No samplingrate defined !');
	disp('Result will be wrong due to this !');
end
narg=nargin;
if narg ==1				% wfft(x)
	Efi=0;
	Eff=0;
elseif ( narg == 2 & ~strcmp(fi,'n') )	% (x,fi)
	Efi= (exist('fi'));
	Eff=0;
elseif ( narg == 2 & strcmp(fi,'n') )	% (x,'n')
	n=fi;
	Efi=0;
	Eff=0;
elseif ( narg == 3 & strcmp(ff,'n') ) 	% (x,fi,'n')
	n=ff;
	Efi= (exist('fi'));
	Eff=0;	
else					% (x,fi,ff)
	Efi=(exist('fi'));
	Eff=(exist('ff'));
end

% Frequencia de Nyquist :
Fn=samplingrate/2;		% (Fn=22050 Hz)

% Proxima potencia de 2 igual ou maior que o comprimento de x:
nfft = 2^(nextpow2(length(x)));	% (nfft=131072)

% Faz-se a FFT acolchoando se necessrio for para um vetor power de 2:
ft=fft(x,nfft);			% (length(ft)=131072)

% Numero de pontos unicos (npu) mapeia de 0 Hz (ponto 1) at a
% frequencia de Nyquist (ponto (nfft/2 + 1) - isto se nfft  par,
% porque se for impar, o que nao desejamos, nao haver frequencia
% de Nyquist calculada, e o numero de pontos unicos s ser 
% (nfft+1)/2 (que d par se nfft for impar, certo?). Anyway,
% para generalizar fazemos o calculo de npu assim:

npu=ceil((nfft+1)/2);		% (npu=65537)

% J que a FFT  simtrica, jogamos a segunda parte fora:
ft=ft(1:npu);			% (length(ft)=npu=65537)

% Calculamos agora a magnitude
magft=abs(ft);			% (length(magft)=npu=65537)

% Multiplicamos por dois para compensar pela perda de energia
% eliminando metade do vetor (a metade que mapeava o semieixo negativo)
magft=magft*2;

% J que o componente DC (no ponto 1, primeiro elemento) nao deve
% participar dessa multiplicacao por 2 acima (nem o ponto referente 
% a frequencia de Nyquist, se houver), fazemos as correcoes:
magft(1)=magft(1)/2;
if ~rem(nfft,2),
	magft(npu)=magft(npu)/2;
end

% Levando-se em conta que o Matlab nao escala a sada da FFT pelo
% comprimento da entrada (length(x)), ns escalamos a FFT tal que
% ela nao seja funao do length(x):
magft=magft/length(x);

% Para normalizar de acordo com o maximo de magft, fazemos o mximo
% de magft ser 1 (100%) se o usuario desejar assim. Basta que ele
% entao chame a funcao com mais um parametro 'n' no final para 
% sinalizar a normalizacao abaixo. Senao, fica sem normalizar.
if (exist('n'))
   magft=magft/max(magft);
end

% Agora criamos um vetor para a frequencia com npu pontos, igualmente 
% espacado entre 0 Hz (ponto 1) e a frequencia de Nyquist (ponto npu,
% quando ela existir, e desejamos que exista. Se fs=44100 KHz, 
% a freq. Nyquist  22050 KHz, e est no ponto (22051)
f=(0:npu-1)*2*Fn/nfft;			% (length(f)=npu=65537)

% Agora preparamos para plotagem da faixa entre fi e ff especificadas:

if Efi
   ki=round((fi*nfft/samplingrate) + 1);
else
   ki=1;
   fi=0;
end
if Eff
   kf=round((ff*nfft/samplingrate) + 1);
else
   kf=length(f);
   ff=Fn;
end

% Agora plotamos

figure(3);
ymax=ceil(max(magft));

plot(f(ki:kf),magft(ki:kf),'b-');
axis([fi ff 0 ymax]);

xlabel('Hz'); ylabel('Magnitude')
title('FFT');

% Parte do Wavesynt para Wavelab
% RRAF 1997 (28.2.97)